@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -192,13 +192,22 @@ static VALUE
 replace_body (VALUE self, VALUE rb_chunk)
 {
     GError *error = NULL;
-    const gchar *chunk;
 
-    chunk = RVAL2CSTR(rb_chunk);
-    if (!milter_client_context_replace_body(SELF(self),
-                                            chunk, RSTRING_LEN(rb_chunk),
-                                            &error))
-        RAISE_GERROR(error);
+    if (RVAL2CBOOL(rb_obj_is_kind_of(rb_chunk, rb_cString))) {
+        const gchar *chunk = RVAL2CSTR(rb_chunk);
+        if (!milter_client_context_replace_body(SELF(self),
+                                                chunk, RSTRING_LEN(rb_chunk),
+                                                &error)) {
+            RAISE_GERROR(error);
+        }
+    } else {
+        GBytes *chunk = RVAL2BOXED(rb_chunk, G_TYPE_BYTES);;
+        if (!milter_client_context_replace_body_bytes(SELF(self),
+                                                      chunk,
+                                                      &error)) {
+            RAISE_GERROR(error);
+        }
+    }
 
     return self;
 }
@@ -264,6 +273,7 @@ set_mail_transaction_shelf_value (VALUE self, VALUE key, VALUE value)
     milter_client_context_set_mail_transaction_shelf_value(SELF(self),
                                                            RVAL2CSTR(key),
                                                            RVAL2CSTR(value));
+    rb_iv_set(self, "@mail_transaction_shelf", RUBY_Qnil);
     return self;
 }
 
@@ -277,7 +287,7 @@ get_mail_transaction_shelf_value (VALUE self, VALUE key)
 }
 
 static void
-build_rb_hash(gpointer key, gpointer value, gpointer data)
+build_rb_hash(const gchar *key, const gchar *value, gpointer data)
 {
     rb_hash_aset((VALUE) data, CSTR2RVAL(key), CSTR2RVAL(value));
 }
@@ -294,9 +304,6 @@ get_mail_transaction_shelf (VALUE self)
     milter_client_context_mail_transaction_shelf_foreach(SELF(self),
                                                          build_rb_hash,
                                                          (gpointer) rb_hash);
-    if (RHASH_EMPTY_P(rb_hash))
-        return Qnil;
-
     shelf = rb_iv_set(self, "@mail_transaction_shelf", rb_hash);
     return shelf;
 }
