@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -13,10 +13,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
-require 'socket'
-require 'tempfile'
-require 'fileutils'
-require 'pathname'
+require "fileutils"
+require "pathname"
+require "rbconfig"
+require "socket"
+require "tempfile"
+require "tmpdir"
 
 module MilterTestUtils
   def fixture_path(*paths)
@@ -26,9 +28,9 @@ end
 
 Milter::Logger.default.target_level = Milter::LOG_LEVEL_NONE
 
-require 'milter-encoder-test-utils'
-require 'milter-manager-encoder-test-utils'
-require 'milter-detector-test-utils'
-require 'milter-parse-test-utils'
-require 'milter-event-loop-test-utils'
-require 'milter-multi-process-test-utils'
+require "milter-encoder-test-utils"
+require "milter-manager-encoder-test-utils"
+require "milter-detector-test-utils"
+require "milter-parse-test-utils"
+require "milter-event-loop-test-utils"
+require "milter-multi-process-test-utils"
