@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -17,18 +17,19 @@
 
 require 'pathname'
 
-base = Pathname.new(__FILE__).dirname.expand_path
-top = (base + "..").expand_path
+test_dir = Pathname.new(__dir__).expand_path
+top_dir = (test_dir + "..").expand_path
 
-test_unit_dir = top + "test-unit" + "lib"
+test_unit_dir = top_dir + "test-unit" + "lib"
 $LOAD_PATH.unshift(test_unit_dir.to_s)
 require 'test/unit'
-require 'test/unit/rr'
 
+lib_dir = top_dir + "lib"
+$LOAD_PATH.unshift(lib_dir.to_s)
 require 'milter/manager'
 
-$LOAD_PATH.unshift(base.to_s)
+$LOAD_PATH.unshift(test_dir.to_s)
 require 'milter-test-utils'
 
 ARGV.unshift("--priority-mode")
-exit Test::Unit::AutoRunner.run(true, base)
+exit(Test::Unit::AutoRunner.run(true, test_dir))
