@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,19 +18,17 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
 #include <stdlib.h>
 
 #include "milter-agent.h"
-#include "milter-marshalers.h"
 #include "milter-enum-types.h"
 #include "milter-utils.h"
 #include "milter-logger.h"
 #include "milter-core-internal.h"
-#include "milter-glib-compatible.h"
 
 #define MILTER_AGENT_GET_PRIVATE(obj)                          \
     (G_TYPE_INSTANCE_GET_PRIVATE((obj),                        \
@@ -69,7 +67,7 @@ enum
 
 static gint signals[LAST_SIGNAL] = {0};
 
-static GMutex *auto_tag_mutex = NULL;
+static GMutex auto_tag_mutex;
 static guint auto_tag = 0;
 
 static void         finished           (MilterFinishedEmittable *emittable);
@@ -102,13 +100,13 @@ static gboolean flush      (MilterAgent     *agent,
 void
 milter_agent_internal_init (void)
 {
-    auto_tag_mutex = g_mutex_new();
+    g_mutex_init(&auto_tag_mutex);
 }
 
 void
 milter_agent_internal_quit (void)
 {
-    g_mutex_free(auto_tag_mutex);
+    g_mutex_clear(&auto_tag_mutex);
 }
 
 
@@ -177,7 +175,7 @@ milter_agent_class_init (MilterAgentClass *klass)
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET(MilterAgentClass, flushed),
                      NULL, NULL,
-                     g_cclosure_marshal_VOID__VOID,
+                     NULL,
                      G_TYPE_NONE, 0);
 
     g_type_class_add_private(gobject_class, sizeof(MilterAgentPrivate));
@@ -217,11 +215,11 @@ constructor (GType type, guint n_props, GObjectConstructParam *props)
     if (agent_class->encoder_new)
         priv->encoder = agent_class->encoder_new(agent);
     if (priv->tag == 0) {
-        g_mutex_lock(auto_tag_mutex);
+        g_mutex_lock(&auto_tag_mutex);
         priv->tag = auto_tag++;
         if (priv->tag == 0)
             priv->tag = auto_tag++;
-        g_mutex_unlock(auto_tag_mutex);
+        g_mutex_unlock(&auto_tag_mutex);
     }
     apply_tag(priv);
 
@@ -597,12 +595,24 @@ milter_agent_set_writer (MilterAgent *agent, MilterWriter *writer)
     }
 }
 
+/**
+ * milter_agent_get_encoder:
+ * @agent: A #MilterAgent.
+ *
+ * Returns: (transfer none): The encoder of the agent.
+ */
 MilterEncoder *
 milter_agent_get_encoder (MilterAgent *agent)
 {
     return MILTER_AGENT_GET_PRIVATE(agent)->encoder;
 }
 
+/**
+ * milter_agent_get_decoder:
+ * @agent: A #MilterAgent.
+ *
+ * Returns: (transfer none): The decoder of the agent.
+ */
 MilterDecoder *
 milter_agent_get_decoder (MilterAgent *agent)
 {
@@ -686,12 +696,25 @@ milter_agent_set_tag (MilterAgent *agent, guint tag)
     apply_tag(priv);
 }
 
+/**
+ * milter_agent_get_event_loop:
+ * @agent: A #MilterAgent.
+ *
+ * Returns: (transfer none): The event loop of the agent.
+ */
 MilterEventLoop *
 milter_agent_get_event_loop (MilterAgent *agent)
 {
     return MILTER_AGENT_GET_PRIVATE(agent)->event_loop;
 }
 
+/**
+ * milter_agent_set_event_loop:
+ * @agent: A #MilterAgent.
+ * @loop: A #MilterEventLoop to be used.
+ *
+ * Sets a new event loop.
+ */
 void
 milter_agent_set_event_loop (MilterAgent *agent, MilterEventLoop *loop)
 {
