@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
@@ -34,7 +34,6 @@
 #include "milter-command-encoder.h"
 #include "milter-logger.h"
 #include "milter-enum-types.h"
-#include "milter-marshalers.h"
 #include "milter-macros-requests.h"
 #include "milter-utils.h"
 
@@ -69,6 +68,16 @@ milter_command_encoder_new (void)
     return g_object_new(MILTER_TYPE_COMMAND_ENCODER, NULL);
 }
 
+/**
+ * milter_command_encoder_encode_negotiate:
+ * @encoder: A #MilterCommandEncoder.
+ * @packet: (out) (array length=packet_size) (element-type guint8) (transfer none):
+ *   Return location for encoded command.
+ * @packet_size: (out): Return location for encoded command size in bytes.
+ * @option: (nullable): A #MilterOption.
+ *
+ * Encodes negotiate command.
+ */
 void
 milter_command_encoder_encode_negotiate (MilterCommandEncoder *encoder,
                                          const gchar **packet,
@@ -192,6 +201,19 @@ encode_connect_unknown (GString *buffer, const struct sockaddr *address)
     g_string_append_c(buffer, MILTER_SOCKET_FAMILY_UNKNOWN);
 }
 
+/**
+ * milter_command_encoder_encode_connect:
+ * @encoder: A #MilterCommandEncoder.
+ * @packet: (out) (array length=packet_size) (element-type guint8) (transfer none):
+ *   Return location for encoded command.
+ * @packet_size: (out): Return location for encoded command size in bytes.
+ * @host_name: A host name connected.
+ * @address: (array length=address_size) (element-type guint8):
+ *   An address connected.
+ * @address_size: The size of @address in bytes.
+ *
+ * Encodes connect command.
+ */
 void
 milter_command_encoder_encode_connect (MilterCommandEncoder *encoder,
                                        const gchar **packet,
@@ -342,11 +364,25 @@ milter_command_encoder_encode_end_of_header (MilterCommandEncoder *encoder,
     milter_encoder_pack(base_encoder, packet, packet_size);
 }
 
+/**
+ * milter_command_encoder_encode_body: (skip)
+ * @encoder: A #MilterCommandEncoder.
+ * @packet: (out) (array length=packet_size) (element-type guint8) (transfer none):
+ *   Return location for encoded command.
+ * @packet_size: (out): Return location for encoded command size in bytes.
+ * @chunk: (array length=chunk_size) (element-type guint8):
+ *   A chunk of body.
+ * @chunk_size: The size of @chunk in bytes.
+ * @packed_size: (out): Return location for packed size in bytes.
+ *
+ * Encodes body command.
+ */
 void
 milter_command_encoder_encode_body (MilterCommandEncoder *encoder,
                                     const gchar **packet,
                                     gsize *packet_size,
-                                    const gchar *chunk, gsize size,
+                                    const gchar *chunk,
+                                    gsize chunk_size,
                                     gsize *packed_size)
 {
     MilterEncoder *base_encoder;
@@ -358,10 +394,10 @@ milter_command_encoder_encode_body (MilterCommandEncoder *encoder,
     buffer = milter_encoder_get_buffer(base_encoder);
 
     g_string_append_c(buffer, MILTER_COMMAND_BODY);
-    if (size > MILTER_CHUNK_SIZE)
+    if (chunk_size > MILTER_CHUNK_SIZE)
         packed_chunk_size = MILTER_CHUNK_SIZE;
     else
-        packed_chunk_size = size;
+        packed_chunk_size = chunk_size;
     g_string_append_len(buffer, chunk, packed_chunk_size);
     milter_encoder_pack(base_encoder, packet, packet_size);
 
@@ -369,6 +405,35 @@ milter_command_encoder_encode_body (MilterCommandEncoder *encoder,
         *packed_size = packed_chunk_size;
 }
 
+/**
+ * milter_command_encoder_encode_body_bytes: (rename-to milter_command_encoder_encode_body)
+ * @encoder: A #MilterCommandEncoder.
+ * @packet: (out) (array length=packet_size) (element-type guint8) (transfer none):
+ *   Return location for encoded command.
+ * @packet_size: (out): Return location for encoded command size in bytes.
+ * @chunk: A chunk of body.
+ * @packed_size: (out): Return location for packed size in bytes.
+ *
+ * Encodes body command.
+ */
+void
+milter_command_encoder_encode_body_bytes (MilterCommandEncoder *encoder,
+                                          const gchar **packet,
+                                          gsize *packet_size,
+                                          GBytes *chunk,
+                                          gsize *packed_size)
+{
+    const gchar *chunk_content = NULL;
+    gsize chunk_size = 0;
+    chunk_content = g_bytes_get_data(chunk, &chunk_size);
+    milter_command_encoder_encode_body(encoder,
+                                       packet,
+                                       packet_size,
+                                       chunk_content,
+                                       chunk_size,
+                                       packed_size);
+}
+
 void
 milter_command_encoder_encode_end_of_message (MilterCommandEncoder *encoder,
                                               const gchar **packet,
@@ -388,6 +453,15 @@ milter_command_encoder_encode_end_of_message (MilterCommandEncoder *encoder,
     milter_encoder_pack(base_encoder, packet, packet_size);
 }
 
+/**
+ * milter_command_encoder_encode_abort:
+ * @encoder: A #MilterCommandEncoder.
+ * @packet: (out) (array length=packet_size) (element-type guint8) (transfer none):
+ *   Return location for encoded command.
+ * @packet_size: (out): Return location for encoded command size in bytes.
+ *
+ * Encodes abort command.
+ */
 void
 milter_command_encoder_encode_abort (MilterCommandEncoder *encoder,
                                      const gchar **packet,
