@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <milter/core.h>
@@ -58,8 +58,6 @@ delegate_glib_log_handlers (void)
 void
 milter_init (void)
 {
-    const gchar *memory_profile_env;
-
     if (initialized) {
         remove_glib_log_handlers();
         delegate_glib_log_handlers();
@@ -68,22 +66,6 @@ milter_init (void)
 
     initialized = TRUE;
 
-    milter_memory_profile_init();
-
-    memory_profile_env = g_getenv("MILTER_MEMORY_PROFILE");
-    if (memory_profile_env && g_str_equal(memory_profile_env, "yes")) {
-        milter_memory_profile_enable();
-    }
-
-#if !GLIB_CHECK_VERSION(2, 32, 0)
-    if (!g_thread_supported())
-        g_thread_init(NULL);
-#endif
-
-#if !GLIB_CHECK_VERSION(2, 36, 0)
-    g_type_init();
-#endif
-
     milter_logger_internal_init();
 
     milter_agent_internal_init();
@@ -105,8 +87,6 @@ milter_quit (void)
 
     milter_logger_internal_quit();
 
-    milter_memory_profile_quit();
-
     initialized = FALSE;
 }
 
