@@ -33,7 +33,6 @@
 #include "milter-logger.h"
 #include "milter-decoder.h"
 #include "milter-enum-types.h"
-#include "milter-marshalers.h"
 
 #define COMMAND_LENGTH_BYTES (sizeof(guint32))
 
@@ -109,7 +108,7 @@ milter_decoder_class_init (MilterDecoderClass *klass)
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET(MilterDecoderClass, decode),
                      NULL, NULL,
-                     _milter_marshal_BOOLEAN__POINTER,
+                     NULL,
                      G_TYPE_BOOLEAN, 1, G_TYPE_POINTER);
 
     g_type_class_add_private(gobject_class, sizeof(MilterDecoderPrivate));
@@ -347,6 +346,17 @@ milter_decoder_decode_header_content (const gchar *buffer, gint length,
     return TRUE;
 }
 
+/**
+ * milter_decoder_decode:
+ * @decoder: A #MilterDecoder.
+ * @chunk: (array length=size) (element-type guint8): The string to be decoded.
+ * @size: The size of @chunk in bytes.
+ * @error: (nullable): Return location for an error, or %NULL.
+ *
+ * Decodes a chunk. You can get decoded data by MilterDecoder::decode signals.
+ *
+ * Returns: %TRUE on success, %FALSE otherwise.
+ */
 gboolean
 milter_decoder_decode (MilterDecoder *decoder, const gchar *chunk, gsize size,
                        GError **error)
@@ -487,6 +497,16 @@ milter_decoder_get_command_length (MilterDecoder *decoder)
     return MILTER_DECODER_GET_PRIVATE(decoder)->command_length;
 }
 
+/**
+ * milter_decoder_decode_negotiate:
+ * @buffer: A buffer that has the target data.
+ * @length: The number of bytes of @buffer.
+ * @processed_length: (out): The number of bytes that are processed.
+ * @error: (nullable): Return location for a #GError or %NULL.
+ *
+ * Returns: (transfer full) (nullable): The decoded #MilterOption on success,
+ *   %NULL on error.
+ */
 MilterOption *
 milter_decoder_decode_negotiate (const gchar *buffer,
                                  gint length,
