@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2010  Nobuyoshi Nakada <nakada@clear-code.com>
- *  Copyright (C) 2011-2013  Kouhei Sutou <nakada@clear-code.com>
+ *  Copyright (C) 2011-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -19,7 +19,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include "milter-event-loop.h"
@@ -216,6 +216,13 @@ milter_event_loop_run_without_custom (MilterEventLoop *loop)
     }
 }
 
+/**
+ * milter_event_loop_set_custom_run_func: (skip)
+ * @loop: A #MilterEventLoop.
+ * @custom_run: A #MilterEventLoopCustomRunFunc.
+ *
+ * Set the custom event runner function to the event loop.
+ */
 void
 milter_event_loop_set_custom_run_func (MilterEventLoop             *loop,
                                        MilterEventLoopCustomRunFunc custom_run)
@@ -228,6 +235,12 @@ milter_event_loop_set_custom_run_func (MilterEventLoop             *loop,
     priv->custom_run = custom_run;
 }
 
+/**
+ * milter_event_loop_get_custom_run_func: (skip)
+ * @loop: A #MilterEventLoop.
+ *
+ * Returns: (nullable): The current custom runner function of this event loop.
+ */
 MilterEventLoopCustomRunFunc
 milter_event_loop_get_custom_run_func (MilterEventLoop *loop)
 {
@@ -286,6 +299,12 @@ milter_event_loop_set_custom_iterate_func (MilterEventLoop             *loop,
     priv->custom_iterate_destroy   = destroy;
 }
 
+/**
+ * milter_event_loop_get_custom_iterate_func: (skip)
+ * @loop: A #MilterEventLoop.
+ *
+ * Returns: (nullable): The current custom iterate function of this event loop.
+ */
 MilterEventLoopCustomIterateFunc
 milter_event_loop_get_custom_iterate_func (MilterEventLoop *loop)
 {
@@ -313,26 +332,52 @@ milter_event_loop_quit (MilterEventLoop *loop)
     priv->depth--;
 }
 
+/**
+ * milter_event_loop_watch_io: (skip)
+ * @loop: A #MilterEventLoop.
+ * @channel: A #GIOChannel.
+ * @condition: The condition to watch for.
+ * @function: The function to call when the condition is satisfied.
+ * @user_data: User data to pass to @function.
+ *
+ * This equals to `milter_event_loop_watch_io_full(loop,
+ * G_PRIORITY_DEFAULT, channel, condition, function, user_data,
+ * NULL)`.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_watch_io (MilterEventLoop *loop,
                             GIOChannel      *channel,
                             GIOCondition     condition,
                             GIOFunc          function,
-                            gpointer         data)
+                            gpointer         user_data)
 {
     return milter_event_loop_watch_io_full(loop, G_PRIORITY_DEFAULT,
                                            channel, condition,
-                                           function, data,
+                                           function, user_data,
                                            NULL);
 }
 
+/**
+ * milter_event_loop_watch_io_full: (rename-to milter_event_loop_watch_io)
+ * @loop: A #MilterEventLoop.
+ * @priority: The priority of the #GIOChannel source.
+ * @channel: A #GIOChannel.
+ * @condition: The condition to watch for.
+ * @function: The function to call when the condition is satisfied.
+ * @user_data: User data to pass to @function.
+ * @notify: (nullable): The function to call when the source is removed.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_watch_io_full (MilterEventLoop *loop,
                                  gint             priority,
                                  GIOChannel      *channel,
                                  GIOCondition     condition,
                                  GIOFunc          function,
-                                 gpointer         data,
+                                 gpointer         user_data,
                                  GDestroyNotify   notify)
 {
     MilterEventLoopClass *loop_class;
@@ -341,27 +386,50 @@ milter_event_loop_watch_io_full (MilterEventLoop *loop,
 
     loop_class = MILTER_EVENT_LOOP_GET_CLASS(loop);
     return loop_class->watch_io_full(loop, priority, channel, condition,
-                                     function, data, notify);
+                                     function, user_data, notify);
 }
 
+/**
+ * milter_event_loop_watch_child: (skip)
+ * @loop: A #MilterEventLoop.
+ * @pid: An ID of the process to watch.
+ * @function: The function to call when the child is finished.
+ * @user_data: User data to pass to @function.
+ *
+ * This equals to `milter_event_loop_watch_child_full(loop,
+ * G_PRIORITY_DEFAULT, pid, function, user_data, NULL)`.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_watch_child (MilterEventLoop *loop,
                                GPid             pid,
                                GChildWatchFunc  function,
-                               gpointer         data)
+                               gpointer         user_data)
 {
     return milter_event_loop_watch_child_full(loop, G_PRIORITY_DEFAULT,
                                               pid,
-                                              function, data,
+                                              function, user_data,
                                               NULL);
 }
 
+/**
+ * milter_event_loop_watch_child_full: (rename-to milter_event_loop_watch_child)
+ * @loop: A #MilterEventLoop.
+ * @priority: The priority of the child source.
+ * @pid: An ID of the process to watch.
+ * @function: The function to call when the child is finished.
+ * @user_data: User data to pass to @function.
+ * @notify: (nullable): The function to call when the source is removed.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_watch_child_full (MilterEventLoop *loop,
                                     gint             priority,
                                     GPid             pid,
                                     GChildWatchFunc  function,
-                                    gpointer         data,
+                                    gpointer         user_data,
                                     GDestroyNotify   notify)
 {
     MilterEventLoopClass *loop_class;
@@ -370,27 +438,51 @@ milter_event_loop_watch_child_full (MilterEventLoop *loop,
 
     loop_class = MILTER_EVENT_LOOP_GET_CLASS(loop);
     return loop_class->watch_child_full(loop, priority, pid,
-                                        function, data, notify);
+                                        function, user_data, notify);
 }
 
+/**
+ * milter_event_loop_add_timeout: (skip)
+ * @loop: A #MilterEventLoop.
+ * @interval_in_seconds: The time between calls to the @function, in seconds.
+ * @function: The function to call when the interval is passed.
+ * @user_data: User data to pass to @function.
+ *
+ * This equals to `milter_event_loop_add_timeout_full(loop,
+ * G_PRIORITY_DEFAULT, interval_in_seconds, function, user_data,
+ * NULL)`.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_add_timeout (MilterEventLoop *loop,
                                gdouble          interval_in_seconds,
                                GSourceFunc      function,
-                               gpointer         data)
+                               gpointer         user_data)
 {
     return milter_event_loop_add_timeout_full(loop, G_PRIORITY_DEFAULT,
                                               interval_in_seconds,
-                                              function, data,
+                                              function, user_data,
                                               NULL);
 }
 
+/**
+ * milter_event_loop_add_timeout_full: (rename-to milter_event_loop_add_timeout)
+ * @loop: A #MilterEventLoop.
+ * @priority: The priority of the timeout source.
+ * @interval_in_seconds: The time between calls to the @function, in seconds.
+ * @function: The function to call when the interval is passed.
+ * @user_data: User data to pass to @function.
+ * @notify: (nullable): The function to call when the source is removed.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_add_timeout_full (MilterEventLoop *loop,
                                     gint             priority,
                                     gdouble          interval_in_seconds,
                                     GSourceFunc      function,
-                                    gpointer         data,
+                                    gpointer         user_data,
                                     GDestroyNotify   notify)
 {
     MilterEventLoopClass *loop_class;
@@ -400,23 +492,44 @@ milter_event_loop_add_timeout_full (MilterEventLoop *loop,
 
     loop_class = MILTER_EVENT_LOOP_GET_CLASS(loop);
     return loop_class->add_timeout_full(loop, priority, interval_in_seconds,
-                                        function, data, notify);
+                                        function, user_data, notify);
 }
 
+/**
+ * milter_event_loop_add_idle: (skip)
+ * @loop: A #MilterEventLoop.
+ * @function: The function to call when no source is dispatched.
+ * @user_data: User data to pass to @function.
+ *
+ * This equals to `milter_event_loop_add_idle_full(loop,
+ * G_PRIORITY_DEFAULT_IDLE, function, user_data, NULL)`.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_add_idle (MilterEventLoop *loop,
                             GSourceFunc      function,
-                            gpointer         data)
+                            gpointer         user_data)
 {
     return milter_event_loop_add_idle_full(loop, G_PRIORITY_DEFAULT_IDLE,
-                                           function, data, NULL);
+                                           function, user_data, NULL);
 }
 
+/**
+ * milter_event_loop_add_idle_full: (rename-to milter_event_loop_add_idle)
+ * @loop: A #MilterEventLoop.
+ * @priority: The priority of the idle source.
+ * @function: The function to call when no source is dispatched.
+ * @user_data: User data to pass to @function.
+ * @notify: (nullable): The function to call when the source is removed.
+ *
+ * Returns: The event source ID.
+ */
 guint
 milter_event_loop_add_idle_full (MilterEventLoop *loop,
                                  gint             priority,
                                  GSourceFunc      function,
-                                 gpointer         data,
+                                 gpointer         user_data,
                                  GDestroyNotify   notify)
 {
     MilterEventLoopClass *loop_class;
@@ -424,7 +537,7 @@ milter_event_loop_add_idle_full (MilterEventLoop *loop,
     g_return_val_if_fail(loop != NULL, 0);
 
     loop_class = MILTER_EVENT_LOOP_GET_CLASS(loop);
-    return loop_class->add_idle_full(loop, priority, function, data, notify);
+    return loop_class->add_idle_full(loop, priority, function, user_data, notify);
 }
 
 gboolean
