@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <errno.h>
@@ -32,7 +32,6 @@
 #include "milter-logger.h"
 #include "milter-core-internal.h"
 #include "milter-utils.h"
-#include "milter-marshalers.h"
 #include "milter-enum-types.h"
 
 #define DEFAULT_KEY "default"
@@ -65,6 +64,7 @@
     }                                                   \
 } while (0)
 
+G_DEFINE_QUARK(milter-logger-error-quark, milter_logger_error)
 
 typedef struct _MilterLoggerPrivate	MilterLoggerPrivate;
 struct _MilterLoggerPrivate
@@ -197,7 +197,7 @@ milter_logger_class_init (MilterLoggerClass *klass)
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET(MilterLoggerClass, log),
                      NULL, NULL,
-                     _milter_marshal_VOID__STRING_FLAGS_STRING_UINT_STRING_POINTER_STRING,
+                     NULL,
                      G_TYPE_NONE, 7,
                      G_TYPE_STRING, MILTER_TYPE_LOG_LEVEL_FLAGS, G_TYPE_STRING,
                      G_TYPE_UINT, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING);
@@ -553,12 +553,32 @@ milter_logger_default_log_handler (MilterLogger *logger, const gchar *domain,
     g_string_free(log, TRUE);
 }
 
+/**
+ * milter_logger:
+ *
+ * Returns: (transfer none): The singleton logger in this process.
+ */
 MilterLogger *
 milter_logger (void)
 {
     return singleton_milter_logger;
 }
 
+/**
+ * milter_logger_get_default:
+ *
+ * This is same as milter_logger().
+ *
+ * Returns: (transfer none): The singleton logger in this process.
+ *
+ * Since: 2.1.6
+ */
+MilterLogger *
+milter_logger_get_default (void)
+{
+    return singleton_milter_logger;
+}
+
 MilterLogger *
 milter_logger_new (void)
 {
@@ -597,6 +617,39 @@ milter_logger_log_va_list (MilterLogger *logger,
     g_free(message);
 }
 
+/**
+ * milter_logger_log_literal:
+ * @logger: A #MilterLogger.
+ * @domain: A log domain.
+ * @level: A log level.
+ * @file: A file name where the log is happened.
+ * @line: A line number where the log is happened.
+ * @function: A function name where the log is happened.
+ * @message: A message to be logged.
+ *
+ * This is for language bindings.
+ *
+ * Since: 2.1.6
+ */
+void
+milter_logger_log_literal (MilterLogger *logger,
+                           const gchar *domain,
+                           MilterLogLevelFlags level,
+                           const gchar *file,
+                           guint line,
+                           const gchar *function,
+                           const gchar *message)
+{
+    milter_logger_log(logger,
+                      domain,
+                      level,
+                      file,
+                      line,
+                      function,
+                      "%s",
+                      message);
+}
+
 void
 milter_logger_reopen (MilterLogger *logger)
 {
@@ -749,6 +802,17 @@ milter_logger_get_path (MilterLogger *logger)
     return MILTER_LOGGER_GET_PRIVATE(logger)->path;
 }
 
+/**
+ * milter_logger_set_path:
+ * @logger: A #MilterLogger.
+ * @path: (nullable): An output path.
+ * @error: (nullable): Return location for a #GError or %NULL.
+ *
+ * Sets output path. If @path is %NULL or `"-"`, log messages are
+ * outputted to the standard output.
+ *
+ * Returns: %TRUE on success, %FALSE otherwise.
+ */
 gboolean
 milter_logger_set_path (MilterLogger *logger, const gchar *path, GError **error)
 {
