@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2009-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2009-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
@@ -437,12 +437,25 @@ milter_message_result_set_from (MilterMessageResult *result,
     priv->from = g_strdup(from);
 }
 
+/**
+ * milter_message_result_get_recipients:
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: (transfer none) (element-type utf8): The recipients of the results.
+ */
 GList *
 milter_message_result_get_recipients (MilterMessageResult *result)
 {
     return MILTER_MESSAGE_RESULT_GET_PRIVATE(result)->recipients;
 }
 
+/**
+ * milter_message_result_set_recipients:
+ * @result: A #MilterMessageResult.
+ * @recipients: (element-type utf8): Recipient names.
+ * 
+ * Set the recipients to the result.
+ */
 void
 milter_message_result_set_recipients (MilterMessageResult *result,
                                       const GList *recipients)
@@ -488,12 +501,26 @@ milter_message_result_remove_recipient (MilterMessageResult *result,
     }
 }
 
+/**
+ * milter_message_result_get_temporary_failed_recipients:
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: (transfer none) (element-type utf8):
+ *   Temporary failed recipients of the result.
+ */
 GList *
 milter_message_result_get_temporary_failed_recipients (MilterMessageResult *result)
 {
     return MILTER_MESSAGE_RESULT_GET_PRIVATE(result)->temporary_failed_recipients;
 }
 
+/**
+ * milter_message_result_set_temporary_failed_recipients:
+ * @result: A #MilterMessageResult.
+ * @recipients: (element-type utf8): Recipient names.
+ *
+ * Set temporary failed recipients to the result.
+ */
 void
 milter_message_result_set_temporary_failed_recipients (MilterMessageResult *result,
                                                        const GList *recipients)
@@ -524,12 +551,26 @@ milter_message_result_add_temporary_failed_recipient (MilterMessageResult *resul
         g_list_append(priv->temporary_failed_recipients, g_strdup(recipient));
 }
 
+/**
+ * milter_message_result_get_rejected_recipients:
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: (transfer none) (element-type utf8):
+ *   Rejected recipients of the result.
+ */
 GList *
 milter_message_result_get_rejected_recipients (MilterMessageResult *result)
 {
     return MILTER_MESSAGE_RESULT_GET_PRIVATE(result)->rejected_recipients;
 }
 
+/**
+ * milter_message_result_set_rejected_recipients:
+ * @result: A #MilterMessageResult.
+ * @recipients: (element-type utf8): Recipient names.
+ *
+ * Set rejected recipients to the result.
+ */
 void
 milter_message_result_set_rejected_recipients (MilterMessageResult *result,
                                                const GList *recipients)
@@ -559,6 +600,12 @@ milter_message_result_add_rejected_recipient (MilterMessageResult *result,
         g_list_append(priv->rejected_recipients, g_strdup(recipient));
 }
 
+/**
+ * milter_message_result_get_headers:
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: (transfer none): The headers of the result.
+ */
 MilterHeaders *
 milter_message_result_get_headers (MilterMessageResult *result)
 {
@@ -636,6 +683,12 @@ milter_message_result_set_status (MilterMessageResult *result,
     priv->status = status;
 }
 
+/**
+ * milter_message_result_get_added_headers:
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: (transfer none): The added headers of the result.
+ */
 MilterHeaders *
 milter_message_result_get_added_headers (MilterMessageResult *result)
 {
@@ -655,6 +708,12 @@ milter_message_result_set_added_headers (MilterMessageResult *result,
         g_object_ref(priv->added_headers);
 }
 
+/**
+ * milter_message_result_get_removed_headers:
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: (transfer none): The removed headers of the result.
+ */
 MilterHeaders *
 milter_message_result_get_removed_headers (MilterMessageResult *result)
 {
@@ -687,6 +746,12 @@ milter_message_result_set_quarantine (MilterMessageResult *result,
     MILTER_MESSAGE_RESULT_GET_PRIVATE(result)->quarantine = quarantine;
 }
 
+/**
+ * milter_message_result_get_start_time: (skip)
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: The start time of the result.
+ */
 GTimeVal *
 milter_message_result_get_start_time (MilterMessageResult *result)
 {
@@ -708,6 +773,12 @@ milter_message_result_set_start_time (MilterMessageResult *result,
     }
 }
 
+/**
+ * milter_message_result_get_end_time: (skip)
+ * @result: A #MilterMessageResult.
+ *
+ * Returns: The end time of the result.
+ */
 GTimeVal *
 milter_message_result_get_end_time (MilterMessageResult *result)
 {
