@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include "milter-option.h"
@@ -183,6 +183,12 @@ milter_option_new_empty (void)
     return g_object_new(MILTER_TYPE_OPTION, NULL);
 }
 
+/**
+ * milter_option_copy:
+ * @option: A option to be copied.
+ *
+ * Returns: (transfer full): The copied option.
+ */
 MilterOption *
 milter_option_copy (MilterOption *option)
 {
