@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,14 +18,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
 #include <stdlib.h>
 
 #include "milter-protocol-agent.h"
-#include "milter-marshalers.h"
 #include "milter-enum-types.h"
 #include "milter-utils.h"
 #include "milter-logger.h"
@@ -205,6 +204,13 @@ milter_protocol_agent_get_macro (MilterProtocolAgent *agent, const gchar *name)
     return value;
 }
 
+/**
+ * milter_protocol_agent_get_available_macros:
+ * @agent: A #MilterProtocolAgent.
+ *
+ * Returns: (transfer none) (element-type utf8 utf8): The available macros of
+ *   the agent.
+ */
 GHashTable *
 milter_protocol_agent_get_available_macros (MilterProtocolAgent *agent)
 {
@@ -235,6 +241,13 @@ milter_protocol_agent_get_available_macros (MilterProtocolAgent *agent)
 
 }
 
+/**
+ * milter_protocol_agent_get_macros:
+ * @agent: A #MilterProtocolAgent.
+ *
+ * Returns: (transfer none) (element-type utf8 utf8) (nullable):
+ *   The macros of the agent.
+ */
 GHashTable *
 milter_protocol_agent_get_macros (MilterProtocolAgent *agent)
 {
@@ -413,6 +426,12 @@ milter_protocol_agent_set_macros_requests (MilterProtocolAgent *agent,
         g_object_ref(priv->macros_requests);
 }
 
+/**
+ * milter_protocol_agent_get_macros_requests:
+ * @agent: A #MilterProtocolAgent.
+ *
+ * Returns: (transfer none): The requested macros of the agent.
+ */
 MilterMacrosRequests *
 milter_protocol_agent_get_macros_requests(MilterProtocolAgent *agent)
 {
