@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
@@ -33,7 +33,6 @@
 #include "milter-reply-encoder.h"
 #include "milter-logger.h"
 #include "milter-enum-types.h"
-#include "milter-marshalers.h"
 #include "milter-macros-requests.h"
 #include "milter-utils.h"
 
@@ -69,10 +68,8 @@ milter_reply_encoder_new (void)
 }
 
 static void
-encode_macros_request (gpointer key, gpointer value, gpointer user_data)
+encode_macros_request (MilterCommand command, GList *symbols, gpointer user_data)
 {
-    MilterCommand command = GPOINTER_TO_INT(key);
-    GList *symbols = value;
     GString *buffer = user_data;
     MilterMacroStage stage, normalized_stage;
     gchar encoded_stage[sizeof(guint32)];
@@ -349,7 +346,7 @@ milter_reply_encoder_encode_change_from (MilterReplyEncoder *encoder,
     g_string_append_c(buffer, MILTER_REPLY_CHANGE_FROM);
     g_string_append(buffer, from);
     g_string_append_c(buffer, '\0');
-    if (parameters && parameters != '\0') {
+    if (parameters && parameters[0] != '\0') {
         g_string_append(buffer, parameters);
         g_string_append_c(buffer, '\0');
     }
