@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2010-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2010-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
@@ -251,12 +251,26 @@ milter_session_result_stop (MilterSessionResult *result)
     }
 }
 
+/**
+ * milter_session_result_get_message_results:
+ * @result: A #MilterSessionResult.
+ *
+ * Returns: (transfer none) (element-type MilterMessageResult): Message results.
+ */
 GList *
 milter_session_result_get_message_results (MilterSessionResult *result)
 {
     return MILTER_SESSION_RESULT_GET_PRIVATE(result)->message_results;
 }
 
+/**
+ * milter_session_result_set_message_results:
+ * @result: A #MilterSessionResult.
+ * @message_results: (element-type MilterMessageResult):
+ *   A list of #MilterMessageResult.
+ *
+ * Set message results.
+ */
 void
 milter_session_result_set_message_results (MilterSessionResult *result,
                                            const GList *message_results)
@@ -286,6 +300,12 @@ milter_session_result_set_disconnected (MilterSessionResult *result,
     MILTER_SESSION_RESULT_GET_PRIVATE(result)->disconnected = disconnected;
 }
 
+/**
+ * milter_session_result_get_start_time: (skip)
+ * @result: A #MilterSessionResult.
+ *
+ * Returns: The start time of the result.
+ */
 GTimeVal *
 milter_session_result_get_start_time (MilterSessionResult *result)
 {
@@ -307,6 +327,12 @@ milter_session_result_set_start_time (MilterSessionResult *result,
     }
 }
 
+/**
+ * milter_session_result_get_end_time: (skip)
+ * @result: A #MilterSessionResult.
+ *
+ * Returns: The end time of the result.
+ */
 GTimeVal *
 milter_session_result_get_end_time (MilterSessionResult *result)
 {
