@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
@@ -432,11 +432,6 @@ inspect_hash_string_string_element (gpointer _key, gpointer _value,
     g_string_append(inspected, ", ");
 }
 
-static gint compare_hash_key(gconstpointer a, gconstpointer b)
-{
-  return g_strcmp0((gchar*)a, (gchar*)b);
-}
-
 gchar *
 milter_utils_inspect_hash_string_string (GHashTable *hash)
 {
@@ -444,14 +439,15 @@ milter_utils_inspect_hash_string_string (GHashTable *hash)
 
     inspected = g_string_new("{");
     if (g_hash_table_size(hash) > 0) {
-        GList *key_list = g_hash_table_get_keys(hash);
-        key_list = g_list_sort(key_list, compare_hash_key);
+        GList *keys = g_hash_table_get_keys(hash);
         const GList *node;
-        for (node = key_list; node; node = g_list_next(node)) {
-            gpointer value = g_hash_table_lookup(hash, node->data);
-            inspect_hash_string_string_element(node->data, value, inspected);
+        keys = g_list_sort(keys, (GCompareFunc)g_strcmp0);
+        for (node = keys; node; node = g_list_next(node)) {
+            gchar *key = node->data;
+            gpointer value = g_hash_table_lookup(hash, key);
+            inspect_hash_string_string_element(key, value, inspected);
         }
-        g_list_free(key_list);
+        g_list_free(keys);
         g_string_truncate(inspected, inspected->len - strlen(", "));
     }
     g_string_append(inspected, "}");
@@ -481,6 +477,15 @@ milter_utils_merge_hash_string_string (GHashTable *dest, GHashTable *src)
                          dest);
 }
 
+
+/**
+ * milter_utils_inspect_list_pointer: (skip)
+ * @list: (element-type void*): A #GList to be inspected.
+ *
+ * Returns: The string that inspects the give list.
+ *
+ *   It should be freed with g_free() when no longer needed.
+ */
 gchar *
 milter_utils_inspect_list_pointer (const GList *list)
 {
@@ -908,6 +913,16 @@ parse_file_mode_numeric (const gchar *string, guint *mode, gchar **error_message
     return TRUE;
 }
 
+/**
+ * milter_utils_parse_file_mode:
+ * @string: a mode string to be parsed.
+ * @mode: (out): return location for parsed mode.
+ * @error_message: (out): return location for error message on error.
+ *
+ * Parses mode string such as "u+rw".
+ *
+ * Returns: %TRUE on success, %FALSE otherwise.
+ */
 gboolean
 milter_utils_parse_file_mode (const gchar *string,
                               guint *mode, gchar **error_message)
