@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <sys/types.h>
@@ -31,7 +31,6 @@
 #include "milter-manager-configuration.h"
 #include "milter-manager-leader.h"
 #include "milter-manager-children.h"
-#include <milter/core/milter-marshalers.h>
 
 #define DEFAULT_FALLBACK_STATUS MILTER_STATUS_ACCEPT
 #define DEFAULT_FALLBACK_STATUS_AT_DISCONNECT MILTER_STATUS_TEMPORARY_FAILURE
@@ -472,7 +471,7 @@ milter_manager_configuration_class_init (MilterManagerConfigurationClass *klass)
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET(MilterManagerConfigurationClass, connected),
                      NULL, NULL,
-                     g_cclosure_marshal_VOID__OBJECT,
+                     NULL,
                      G_TYPE_NONE, 1, MILTER_TYPE_MANAGER_LEADER);
 
     signals[TO_XML] =
@@ -481,7 +480,7 @@ milter_manager_configuration_class_init (MilterManagerConfigurationClass *klass)
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET(MilterManagerConfigurationClass, to_xml),
                      NULL, NULL,
-                     _milter_marshal_VOID__POINTER_UINT,
+                     NULL,
                      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_UINT);
 
     g_type_class_add_private(gobject_class,
@@ -909,6 +908,14 @@ milter_manager_configuration_instantiate_va_list (const gchar *first_property,
     return MILTER_MANAGER_CONFIGURATION(configuration);
 }
 
+/**
+ * milter_manager_configuration_instantiate: (skip)
+ * @first_property: The value of the first property.
+ * 
+ * This function takes the property values as variable length arguments.
+ *
+ * Returns: (transfer full): A newly created #MilterManagerConfiguration.
+ */
 MilterManagerConfiguration *
 milter_manager_configuration_instantiate (const gchar *first_property,
                                           ...)
@@ -982,6 +989,13 @@ milter_manager_configuration_clear_load_paths (MilterManagerConfiguration *confi
     }
 }
 
+/**
+ * milter_manager_configuration_get_load_paths:
+ * @configuration: A #MilterManagerConfiguration.
+ *
+ * Returns: (transfer none) (element-type utf8):
+ *   A list of load paths of @configuration.
+ */
 const GList *
 milter_manager_configuration_get_load_paths (MilterManagerConfiguration *configuration)
 {
@@ -1639,6 +1653,14 @@ milter_manager_configuration_add_egg (MilterManagerConfiguration *configuration,
     priv->eggs = g_list_append(priv->eggs, egg);
 }
 
+/**
+ * milter_manager_configuration_find_egg:
+ * @configuration: A #MilterManagerConfiguration.
+ * @name: The name of the egg to find.
+ *
+ * Returns: (transfer none) (nullable):
+ *   The #MilterManagerEgg if it exists, %NULL otherwise.
+ */
 MilterManagerEgg *
 milter_manager_configuration_find_egg (MilterManagerConfiguration *configuration,
                                        const gchar *name)
@@ -1658,6 +1680,13 @@ milter_manager_configuration_find_egg (MilterManagerConfiguration *configuration
     return NULL;
 }
 
+/**
+ * milter_manager_configuration_get_eggs:
+ * @configuration: A #MilterManagerConfiguration.
+ *
+ * Returns: (transfer none) (element-type MilterManagerEgg):
+ *   A list of #MilterManagerEgg.
+ */
 const GList *
 milter_manager_configuration_get_eggs (MilterManagerConfiguration *configuration)
 {
@@ -1833,6 +1862,14 @@ milter_manager_configuration_add_applicable_condition (MilterManagerConfiguratio
         g_list_append(priv->applicable_conditions, condition);
 }
 
+/**
+ * milter_manager_configuration_find_applicable_condition:
+ * @configuration: A #MilterManagerConfiguration.
+ * @name: The name of the applicable condition to find.
+ *
+ * Returns: (transfer none) (nullable):
+ *   The #MilterManagerApplicableCondition if it exists, %NULL otherwise.
+ */
 MilterManagerApplicableCondition *
 milter_manager_configuration_find_applicable_condition (MilterManagerConfiguration *configuration,
                                                         const gchar *name)
@@ -1854,6 +1891,13 @@ milter_manager_configuration_find_applicable_condition (MilterManagerConfigurati
     return NULL;
 }
 
+/**
+ * milter_manager_configuration_get_applicable_conditions:
+ * @configuration: A #MilterManagerConfiguration.
+ *
+ * Returns: (transfer none) (element-type MilterManagerApplicableCondition):
+ *   A list of #MilterManagerApplicableCondition.
+ */
 const GList *
 milter_manager_configuration_get_applicable_conditions (MilterManagerConfiguration *configuration)
 {
@@ -2267,6 +2311,12 @@ milter_manager_configuration_get_location (MilterManagerConfiguration *configura
     return g_hash_table_lookup(priv->locations, key);
 }
 
+/**
+ * milter_manager_configuration_get_locations:
+ * @configuration: A #MilterManagerConfiguration.
+ *
+ * Returns: (transfer none): Locations of @configuration.
+ */
 GHashTable *
 milter_manager_configuration_get_locations (MilterManagerConfiguration *configuration)
 {
