@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,10 +18,9 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
-#include <milter/core/milter-marshalers.h>
 #include "milter-manager-leader.h"
 #include "milter-manager-enum-types.h"
 #include "milter-manager-children.h"
@@ -133,7 +132,7 @@ milter_manager_leader_class_init (MilterManagerLeaderClass *klass)
                      G_SIGNAL_RUN_LAST,
                      G_STRUCT_OFFSET(MilterManagerLeaderClass, connection_check),
                      boolean_handled_accumulator, NULL,
-                     _milter_marshal_BOOLEAN__VOID,
+                     NULL,
                      G_TYPE_BOOLEAN, 0, G_TYPE_NONE);
 
     g_type_class_add_private(gobject_class,
@@ -1330,6 +1329,12 @@ milter_manager_leader_timeout (MilterManagerLeader *leader)
     milter_manager_leader_quit(leader);
 }
 
+/**
+ * milter_manager_leader_get_configuration:
+ * @leader: A #MilterManagerLeader.
+ *
+ * Returns: (transfer none): The configuration of @leader.
+ */
 MilterManagerConfiguration *
 milter_manager_leader_get_configuration (MilterManagerLeader *leader)
 {
@@ -1358,6 +1363,12 @@ milter_manager_leader_set_launcher_channel (MilterManagerLeader *leader,
         g_io_channel_ref(priv->launcher_read_channel);
 }
 
+/**
+ * milter_manager_leader_get_children:
+ * @leader: A #MilterManagerLeader.
+ *
+ * Returns: (transfer none): The chidren of @manager.
+ */
 MilterManagerChildren *
 milter_manager_leader_get_children (MilterManagerLeader *leader)
 {
