@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
@@ -110,7 +110,7 @@ load (GTypeModule *module)
         return FALSE;
 
     if (!_milter_manager_module_load_func(priv->library,
-                               G_STRINGIFY(MILTER_MANAGER_MODULE_IMPL_INIT),
+                                          G_STRINGIFY(MILTER_MANAGER_MODULE_IMPL_INIT),
                                           (gpointer)&priv->init) ||
         !_milter_manager_module_load_func(priv->library,
                                           G_STRINGIFY(MILTER_MANAGER_MODULE_IMPL_EXIT),
@@ -158,6 +158,14 @@ unload (GTypeModule *module)
     cleanup(MILTER_MANAGER_MODULE(module));
 }
 
+/**
+ * milter_manager_module_collect_registered_types:
+ * @modules: (element-type MilterManagerModule):
+ *   A list of #MilterManagerModule.
+ *
+ * Returns: (transfer container) (element-type utf8):
+ *   Registered type names of @modules.
+ */
 GList *
 milter_manager_module_collect_registered_types (GList *modules)
 {
@@ -187,6 +195,14 @@ milter_manager_module_collect_registered_types (GList *modules)
     return results;
 }
 
+/**
+ * milter_manager_module_collect_names:
+ * @modules: (element-type MilterManagerModule):
+ *   A list of #MilterManagerModule.
+ *
+ * Returns: (transfer container) (element-type utf8):
+ *    Names of @modules.
+ */
 GList *
 milter_manager_module_collect_names (GList *modules)
 {
@@ -219,6 +235,15 @@ _milter_manager_module_show_error (GModule *module)
     }
 }
 
+/**
+ * milter_manager_module_find:
+ * @modules: (element-type MilterManagerModule):
+ *   A list of #MilterManagerModule.
+ * @name: The name of the module to find.
+ *
+ * Returns: (transfer none) (nullable):
+ *   The #MilterManagerModule if it exists, %NULL otherwise.
+ */
 MilterManagerModule *
 milter_manager_module_find (GList *modules, const gchar *name)
 {
@@ -236,6 +261,14 @@ milter_manager_module_find (GList *modules, const gchar *name)
     return NULL;
 }
 
+/**
+ * milter_manager_module_instantiate: (skip)
+ * @module: A #MilterMacrosRequests.
+ * @first_property: The value of the first property.
+ * @var_args: The values for the second and subsequent properties.
+ *
+ * Returns: (transfer full): A newly instantiated object provided by @module.
+ */
 GObject *
 milter_manager_module_instantiate (MilterManagerModule *module,
                         const gchar *first_property, va_list var_args)
@@ -294,6 +327,13 @@ _milter_manager_module_load_func (GModule *module, const gchar *func_name,
     }
 }
 
+/**
+ * milter_manager_module_load_module:
+ * @base_dir: The base directory name of a module to load.
+ * @name: The name of a module to load.
+ *
+ * Returns: (transfer full): A loaded module.
+ */
 MilterManagerModule *
 milter_manager_module_load_module (const gchar *base_dir, const gchar *name)
 {
@@ -330,12 +370,28 @@ milter_manager_module_load_module (const gchar *base_dir, const gchar *name)
     return module;
 }
 
+/**
+ * milter_manager_module_load_modules:
+ * @base_dir: The base directory name of modules to load.
+ *
+ * Returns: (transfer full) (element-type MilterManagerModule):
+ *   Loaded modules.
+ */
 GList *
 milter_manager_module_load_modules (const gchar *base_dir)
 {
     return milter_manager_module_load_modules_unique(base_dir, NULL);
 }
 
+/**
+ * milter_manager_module_load_modules_unique:
+ * @base_dir: The base directory name of modules to load.
+ * @exist_modules: (element-type MilterManagerModule):
+ *   Exising modules to be excluded from newly loading.
+ *
+ * Returns: (transfer full) (element-type MilterManagerModule):
+ *   Loaded modules.
+ */
 GList *
 milter_manager_module_load_modules_unique (const gchar *base_dir,
                                            GList *exist_modules)
