@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../../config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <locale.h>
@@ -1407,12 +1407,25 @@ worker_created (MilterClient *client)
     milter_debug("[manager][worker-created] pid=<%d>", getpid());
 }
 
+/**
+ * milter_manager_get_configuration:
+ * @manager: A #MilterManager.
+ *
+ * Returns: (transfer none): The configuration of @manager.
+ */
 MilterManagerConfiguration *
 milter_manager_get_configuration (MilterManager *manager)
 {
     return MILTER_MANAGER_GET_PRIVATE(manager)->configuration;
 }
 
+/**
+ * milter_manager_get_leaders:
+ * @manager: A #MilterManager.
+ *
+ * Returns: (transfer none) (element-type MilterManagerLeader):
+ *   The leaders of @manager.
+ */
 const GList *
 milter_manager_get_leaders (MilterManager *manager)
 {
