@@ -17,28 +17,17 @@
  *
  */
 
-#include <rb-milter-manager.h>
-
-#undef PACKAGE_NAME
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef PACKAGE_STRING
-#undef PACKAGE_BUGREPORT
-
 #ifdef HAVE_CONFIG_H
-#  include "../../../config.h"
-#endif /* HAVE_CONFIG_H */
-
+#  include <config.h>
+#endif
 
 #include <signal.h>
 #include <gmodule.h>
 
-#include <milter/manager/milter-manager-configuration.h>
-#include <milter/manager/milter-manager-module-impl.h>
+#include <rbgobject.h>
 
-#ifndef HAVE_RB_ERRINFO
-#  define rb_errinfo() (ruby_errinfo)
-#endif
+#include <milter/manager.h>
+#include <milter/manager/milter-manager-module-impl.h>
 
 #define MILTER_TYPE_MANAGER_RUBY_CONFIGURATION            (milter_manager_ruby_configuration_get_type())
 #define MILTER_MANAGER_RUBY_CONFIGURATION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), MILTER_TYPE_MANAGER_RUBY_CONFIGURATION, MilterManagerRubyConfiguration))
@@ -166,18 +155,18 @@ milter_manager_ruby_configuration_register_type (GTypeModule *type_module)
 static void
 ruby_init_without_signal_change (void)
 {
-    RETSIGTYPE (*sigint_handler)_((int));
+    void (*sigint_handler)_((int));
 #ifdef SIGHUP
-    RETSIGTYPE (*sighup_handler)_((int));
+    void (*sighup_handler)_((int));
 #endif
 #ifdef SIGQUIT
-    RETSIGTYPE (*sigquit_handler)_((int));
+    void (*sigquit_handler)_((int));
 #endif
 #ifdef SIGTERM
-    RETSIGTYPE (*sigterm_handler)_((int));
+    void (*sigterm_handler)_((int));
 #endif
 #ifdef SIGSEGV
-    RETSIGTYPE (*sigsegv_handler)_((int));
+    void (*sigsegv_handler)_((int));
 #endif
 
     sigint_handler = signal(SIGINT, SIG_DFL);
@@ -288,17 +277,13 @@ add_load_path (void)
     if (milter_manager_rubylib) {
         ruby_incpush(milter_manager_rubylib);
     }
-    ruby_incpush(BINDING_LIB_DIR);
-    ruby_incpush(BINDING_EXT_DIR);
-}
-
-#if RBGLIB_MINOR_VERSION == 17
-static gboolean
-cb_dummy (gpointer data)
-{
-    return FALSE;
-}
+#ifdef RUBY_BINDINGS_LIB_DIR
+    ruby_incpush(RUBY_BINDINGS_LIB_DIR);
 #endif
+#ifdef RUBY_BINDINGS_EXT_DIR
+    ruby_incpush(RUBY_BINDINGS_EXT_DIR);
+#endif
+}
 
 static void
 load_libraries (void)
@@ -306,17 +291,6 @@ load_libraries (void)
     VALUE milter, milter_manager;
     GError *error = NULL;
 
-#if RBGLIB_MINOR_VERSION == 17
-    {
-        guint id;
-
-        do {
-            id = g_idle_add(cb_dummy, NULL);
-            g_source_remove(id);
-        } while (id % 2 == 0);
-    }
-#endif
-
     rb_funcall_protect(&error,
                        Qnil, rb_intern("require"),
                        1, rb_str_new2("milter/manager"));
@@ -360,9 +334,6 @@ init_ruby (void)
     add_load_path();
     ruby_process_options(argc, argv);
     load_libraries();
-#if RBGLIB_MINOR_VERSION <= 16
-    g_main_context_set_poll_func(NULL, NULL);
-#endif
     rb_milter_ruby_interpreter_initialized = TRUE;
 }
 
@@ -386,34 +357,7 @@ MILTER_MANAGER_MODULE_IMPL_INIT (GTypeModule *type_module)
 static void
 ruby_cleanup_without_signal_change (int exit_code)
 {
-    RETSIGTYPE (*sigint_handler)_((int));
-#ifdef HAVE_RB_THREAD_RESET_TIMER_THREAD
-    const gchar *milter_manager_ruby_reset_timer_thread_before_cleanup = NULL;
-#endif
-#ifdef HAVE_RB_THREAD_STOP_TIMER_THREAD
-    const gchar *milter_manager_ruby_stop_timer_thread_before_cleanup;
-#endif
-
-#ifdef HAVE_RB_THREAD_RESET_TIMER_THREAD
-    milter_manager_ruby_reset_timer_thread_before_cleanup =
-        g_getenv("MILTER_MANAGER_RUBY_RESET_TIMER_THREAD_BEFORE_CLEANUP");
-    if (milter_manager_ruby_reset_timer_thread_before_cleanup &&
-        strcmp(milter_manager_ruby_reset_timer_thread_before_cleanup, "yes") == 0) {
-        void rb_thread_reset_timer_thread(void);
-        rb_thread_reset_timer_thread();
-    }
-#endif
-
-#ifdef HAVE_RB_THREAD_STOP_TIMER_THREAD
-    milter_manager_ruby_stop_timer_thread_before_cleanup =
-        g_getenv("MILTER_MANAGER_RUBY_STOP_TIMER_THREAD_BEFORE_CLEANUP");
-    if (milter_manager_ruby_stop_timer_thread_before_cleanup &&
-        strcmp(milter_manager_ruby_stop_timer_thread_before_cleanup, "yes") == 0) {
-        void rb_thread_stop_timer_thread(void);
-        rb_thread_stop_timer_thread();
-    }
-#endif
-
+    void (*sigint_handler)_((int));
     sigint_handler = signal(SIGINT, SIG_DFL);
     ruby_cleanup(exit_code);
     signal(SIGINT, sigint_handler);
@@ -558,7 +502,7 @@ real_event_loop_created (MilterManagerConfiguration *_configuration,
     if (local_error) {
         success = FALSE;
         if (!error) {
-            milter_error("[ruby-configuration][error][event-loop_created] %s",
+            milter_error("[ruby-configuration][error][event-loop-created] %s",
                          local_error->message);
         }
         g_propagate_error(error, local_error);
@@ -616,10 +560,6 @@ real_clear (MilterManagerConfiguration *_configuration, GError **error)
 static GPid
 real_fork (MilterManagerConfiguration *_configuration)
 {
-#ifdef HAVE_RB_FORK
-    int status;
-    return (GPid)rb_fork(&status, NULL, NULL, Qnil);
-#else
     VALUE pid;
 
     pid = rb_funcall2(rb_mKernel, rb_intern("fork"), 0, 0);
@@ -628,7 +568,6 @@ real_fork (MilterManagerConfiguration *_configuration)
     } else {
 	return (GPid)NUM2INT(pid);
     }
-#endif
 }
 
 /*
