@@ -17,6 +17,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <sys/un.h>
