@@ -17,6 +17,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
 #include <libmilter/mfapi.h>
 #include <libmilter/libmilter-compatible.h>
