@@ -17,6 +17,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <string.h>
 
 #include <milter/manager/milter-manager-leader.h>
@@ -71,8 +75,9 @@ static MilterStatus response_status;
 void
 cut_startup (void)
 {
-    MILTER_TYPE_CLIENT_CONTEXT_ERROR;
-    MILTER_TYPE_MANAGER_CHILDREN_ERROR;
+    /* Ensure defining types */
+    g_type_name(MILTER_TYPE_CLIENT_CONTEXT_ERROR);
+    g_type_name(MILTER_TYPE_MANAGER_CHILDREN_ERROR);
 }
 
 static void
