@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2010  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2009-2022  Sutou Kouhei <kou@clear-code.com>
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -15,17 +15,23 @@
 
 class TestLogAnalyzer < Test::Unit::TestCase
   def setup
+    begin
+      pid = spawn("rrdtool", "--version",
+                  out: File::NULL,
+                  err: File::NULL)
+      _, status = Process.waitpid2(pid)
+      omit("rrdtool isn't available") unless status.success?
+    rescue SystemCallError
+      omit("rrdtool isn't available")
+    end
+
     base = Pathname(__FILE__).dirname
     @data_dir = base + "fixtures"
-    @tmp_dir = base + "tmp"
-    FileUtils.rm_rf(@tmp_dir.to_s)
-    FileUtils.mkdir_p(@tmp_dir.to_s)
-
-    @analyzer = analyzer
-  end
-
-  def teardown
-    FileUtils.rm_rf(@tmp_dir.to_s)
+    Dir.mktmpdir do |tmp_dir|
+      @tmp_dir = Pathname(tmp_dir)
+      @analyzer = analyzer
+      yield
+    end
   end
 
   priority :must
@@ -108,6 +114,7 @@ class TestLogAnalyzer < Test::Unit::TestCase
 
   def test_update_with_distance
     FileUtils.cp(Dir.glob((@data_dir + "*.rrd").to_s), @tmp_dir)
+    FileUtils.chmod("u+w", Dir.glob((@tmp_dir + "*.rrd").to_s))
 
     @analyzer.output_directory = @tmp_dir.to_s
     @analyzer.prepare
@@ -175,8 +182,19 @@ EOH
   def fetch(path, start_time, end_time)
     start_time = rrdtool_time_format(start_time)
     end_time = rrdtool_time_format(end_time)
-    result = `rrdtool fetch '#{path}' MAX -s '#{start_time}' -e '#{end_time}'`
-    parse_fetched_data(result)
+    output = Tempfile.new("rrdtool-fetch")
+    output.close
+    pid = spawn({"TZ" => "Asia/Tokyo"},
+                "rrdtool",
+                "fetch",
+                path,
+                "MAX",
+                "-s", start_time,
+                "-e", end_time,
+                out: output.path)
+    Process.waitpid(pid)
+    output.open
+    parse_fetched_data(output.read)
   end
 
   def parse_fetched_data(raw_data)
