@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2022  Sutou Kouhei <kou@clear-code.com>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../config.h"
-#endif /* HAVE_CONFIG_H */
+#  include <config.h>
+#endif
 
 #include <stdlib.h>
 #include <string.h>
@@ -40,11 +40,11 @@
 
 #include <milter/server.h>
 #include <milter/core.h>
-#include <milter/core/milter-glib-compatible.h>
 
 #define DEFAULT_NEGOTIATE_VERSION 6
 #define MILTER_TEST_SERVER_ALL_TIMEOUTS_UNSPECIFIED -1.0
 
+static const gchar *program_name = NULL;
 static gboolean verbose = FALSE;
 static gboolean output_message = FALSE;
 static gchar *spec = NULL;
@@ -102,6 +102,7 @@ typedef struct _ProcessData
 {
     MilterEventLoop *loop;
     GTimer *timer;
+    gboolean succeeded_to_connect;
     gboolean success;
     guint reply_code;
     gchar *reply_extended_code;
@@ -159,12 +160,10 @@ send_abort (MilterServerContext *context, ProcessData *data)
 }
 
 static void
-set_macro (gpointer key, gpointer value, gpointer user_data)
+set_macro (MilterCommand command, GList *symbols, gpointer user_data)
 {
     MilterProtocolAgent *agent = user_data;
     GList *symbol;
-    MilterCommand command = GPOINTER_TO_UINT(key);
-    GList *symbols = value;
 
     for (symbol = symbols; symbol; symbol = g_list_next(symbols)) {
         milter_protocol_agent_set_macro(agent,
@@ -473,7 +472,8 @@ cb_negotiate_reply (MilterServerContext *context, MilterOption *option,
         data->option = g_object_ref(option);
         if (macros_requests)
             milter_macros_requests_foreach(macros_requests,
-                                           (GHFunc)set_macro, context);
+                                           set_macro,
+                                           context);
         cb_continue(context, user_data);
     }
 }
@@ -920,6 +920,7 @@ static void
 cb_ready (MilterServerContext *context, gpointer user_data)
 {
     ProcessData *data = user_data;
+    data->succeeded_to_connect = TRUE;
     setup(context, data);
     g_timer_start(data->timer);
     negotiate(context);
@@ -930,6 +931,7 @@ cb_connection_error (MilterErrorEmittable *emittable, GError *error, gpointer us
 {
     ProcessData *data = user_data;
 
+    data->succeeded_to_connect = FALSE;
     data->success = FALSE;
     data->error = g_error_copy(error);
     milter_event_loop_quit(data->loop);
@@ -951,7 +953,7 @@ print_version (const gchar *option_name,
                gpointer data,
                GError **error)
 {
-    g_print("%s %s\n", g_get_prgname(), VERSION);
+    g_print("%s %s\n", program_name, VERSION);
     exit(EXIT_SUCCESS);
     return TRUE;
 }
@@ -1405,7 +1407,7 @@ parse_mail_contents (const gchar *contents, GError **error)
     first_lines = lines;
 
     /* Ignore mbox separation 'From ' mark. */
-    if (g_str_has_prefix(*lines, "From "))
+    if (*lines && g_str_has_prefix(*lines, "From "))
         lines++;
 
     if (!parse_mail_contents_header_part(&lines, error)) {
@@ -1676,6 +1678,7 @@ init_process_data (ProcessData *data)
 {
     data->loop = milter_glib_event_loop_new(NULL);
     data->timer = g_timer_new();
+    data->succeeded_to_connect = TRUE;
     data->success = TRUE;
     data->quarantine_reason = NULL;
     data->option = NULL;
@@ -1738,31 +1741,11 @@ macros_new (void)
     return g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 }
 
-static gboolean
-pre_option_parse (GOptionContext *option_context,
-                  GOptionGroup *option_group,
-                  gpointer data,
-                  GError **error)
-{
-    option_headers = milter_headers_new();
-    use_color = milter_utils_guess_console_color_usability();
-
-    connect_macros = macros_new();
-    helo_macros = macros_new();
-    envelope_from_macros = macros_new();
-    envelope_recipient_macros = macros_new();
-    data_macros = macros_new();
-    end_of_header_macros = macros_new();
-    end_of_message_macros = macros_new();
-
-    return TRUE;
-}
-
 static void
-apply_options_to_connect_macros (void)
+pre_add_default_connect_macros (void)
 {
     add_macro_values(connect_macros,
-                     "{daemon_name}", g_get_prgname(),
+                     "{daemon_name}", program_name,
                      "{if_name}", "localhost",
                      "{if_addr}", "127.0.0.1",
                      "j", "mail.example.com",
@@ -1770,7 +1753,7 @@ apply_options_to_connect_macros (void)
 }
 
 static void
-apply_options_to_helo_macros (void)
+pre_add_default_helo_macros (void)
 {
     add_macro_values(helo_macros,
                      "{tls_version}", "0",
@@ -1782,15 +1765,100 @@ apply_options_to_helo_macros (void)
 }
 
 static void
-apply_options_to_envelope_from_macros (void)
+pre_add_default_envelope_from_macros (void)
 {
     add_macro_values(envelope_from_macros,
-                     "i", "i",
                      "{mail_mailer}", "mail_mailer",
                      "{mail_host}", "mail_host",
                      "{mail_addr}", "mail_addr",
                      NULL);
+}
 
+static void
+pre_add_default_envelope_recipient_macros (void)
+{
+    add_macro_values(envelope_recipient_macros,
+                     "{rcpt_mailer}", "rcpt_mailer",
+                     "{rcpt_host}", "rcpt_host",
+                     NULL);
+}
+
+static void
+pre_add_default_data_macros (void)
+{
+    add_macro_values(data_macros,
+                     "i", "i",
+                     NULL);
+}
+
+static void
+pre_add_default_end_of_header_macros (void)
+{
+    add_macro_values(end_of_header_macros,
+                     "i", "i",
+                     NULL);
+}
+
+static void
+pre_add_default_end_of_message_macros (void)
+{
+    add_macro_values(end_of_message_macros,
+                     "i", "i",
+                     NULL);
+}
+
+static void
+pre_add_default_macros (void)
+{
+    pre_add_default_connect_macros();
+    pre_add_default_helo_macros();
+    pre_add_default_envelope_from_macros();
+    pre_add_default_envelope_recipient_macros();
+    pre_add_default_data_macros();
+    pre_add_default_end_of_header_macros();
+    pre_add_default_end_of_message_macros();
+}
+
+static gboolean
+pre_option_parse (GOptionContext *option_context,
+                  GOptionGroup *option_group,
+                  gpointer data,
+                  GError **error)
+{
+    program_name = g_get_prgname();
+    if (g_str_has_prefix(program_name, "lt-")) {
+        program_name += strlen("lt-");
+    }
+
+    option_headers = milter_headers_new();
+    use_color = milter_utils_guess_console_color_usability();
+
+    connect_macros = macros_new();
+    helo_macros = macros_new();
+    envelope_from_macros = macros_new();
+    envelope_recipient_macros = macros_new();
+    data_macros = macros_new();
+    end_of_header_macros = macros_new();
+    end_of_message_macros = macros_new();
+
+    pre_add_default_macros();
+
+    return TRUE;
+}
+
+static void
+post_apply_options_to_connect_macros (void)
+{
+}
+
+static void
+post_apply_options_to_helo_macros (void)
+{
+}
+
+static void
+post_apply_options_to_envelope_from_macros (void)
+{
     if (authenticated_name)
         add_macro_values(envelope_from_macros,
                          "{auth_authen}", authenticated_name,
@@ -1806,42 +1874,35 @@ apply_options_to_envelope_from_macros (void)
 }
 
 static void
-apply_options_to_envelope_recipient_macros (void)
-{
-    add_macro_values(envelope_recipient_macros,
-                     "{rcpt_mailer}", "rcpt_mailer",
-                     "{rcpt_host}", "rcpt_host",
-                     NULL);
-}
-
-static void
-apply_options_to_data_macros (void)
+post_apply_options_to_envelope_recipient_macros (void)
 {
 }
 
 static void
-apply_options_to_end_of_header_macros (void)
+post_apply_options_to_data_macros (void)
 {
 }
 
 static void
-apply_options_to_end_of_message_macros (void)
+post_apply_options_to_end_of_header_macros (void)
 {
-    add_macro_values(end_of_message_macros,
-                     "i", "message-id",
-                     NULL);
 }
 
 static void
-apply_options_to_macros (void)
+post_apply_options_to_end_of_message_macros (void)
 {
-    apply_options_to_connect_macros();
-    apply_options_to_helo_macros();
-    apply_options_to_envelope_from_macros();
-    apply_options_to_envelope_recipient_macros();
-    apply_options_to_data_macros();
-    apply_options_to_end_of_header_macros();
-    apply_options_to_end_of_message_macros();
+}
+
+static void
+post_apply_options_to_macros (void)
+{
+    post_apply_options_to_connect_macros();
+    post_apply_options_to_helo_macros();
+    post_apply_options_to_envelope_from_macros();
+    post_apply_options_to_envelope_recipient_macros();
+    post_apply_options_to_data_macros();
+    post_apply_options_to_end_of_header_macros();
+    post_apply_options_to_end_of_message_macros();
 }
 
 static gboolean
@@ -1886,7 +1947,7 @@ post_option_parse (GOptionContext *option_context,
         body_chunks = g_strsplit(body, ",", -1);
     }
 
-    apply_options_to_macros();
+    post_apply_options_to_macros();
 
     return TRUE;
 }
@@ -2288,7 +2349,7 @@ start_process (MilterServerContext *context, ProcessData *process_data)
 
     print_result(context, process_data);
 
-    return TRUE;
+    return process_data->succeeded_to_connect;
 }
 
 static gpointer
